/*=====================================================================

PIXHAWK Micro Air Vehicle Flying Robotics Toolkit

(c) 2009, 2010 PIXHAWK PROJECT  <http://pixhawk.ethz.ch>

This file is part of the PIXHAWK project

    PIXHAWK is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    PIXHAWK is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with PIXHAWK. If not, see <http://www.gnu.org/licenses/>.

======================================================================*/

/**
 * @file
 *   @brief Definition of class ParamParamTreeModel
 *   @author Lorenz Meier <mavteam@student.ethz.ch>
 *
 */

#ifndef PARAMTREEMODEL_H
#define PARAMTREEMODEL_H

#include <QAbstractItemModel>
#include <QModelIndex>
#include <QVariant>

class ParamTreeItem;

class ParamTreeModel : public QAbstractItemModel
{
    Q_OBJECT

public:
    ParamTreeModel(QObject *parent = 0);
    ParamTreeModel(const QString &data, QObject *parent = 0);
    ~ParamTreeModel();

    QVariant data(const QModelIndex &index, int role) const;
    Qt::ItemFlags flags(const QModelIndex &index) const;
    QVariant headerData(int section, Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const;
    QModelIndex index(int row, int column,
                      const QModelIndex &parent = QModelIndex()) const;
    QModelIndex parent(const QModelIndex &index) const;
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    int columnCount(const QModelIndex &parent = QModelIndex()) const;

public slots:
    /** @brief Add a new parameter */
    void appendParam(int componentId, int id, QString name, float value);
    /** @brief Add a new component for this system */
    void appendComponent(int componentId, QString name);

protected:
    ParamTreeItem* getNodeForComponentId(int id);

    QMap<int, ParamTreeItem*> components;

private:
    void setupModelData(const QStringList &lines, ParamTreeItem *parent);

    ParamTreeItem *rootItem;
};
#endif // PARAMParamTreeModel_H
